@@ -1,4 +1,4 @@
-# $Id: ODBC.pm 246 2004-03-26 14:17:35Z jurl $
+# $Id: ODBC.pm 484 2004-10-11 19:20:51Z jurl $
 #
 # Copyright (c) 1994,1995,1996,1998  Tim Bunce
 # portions Copyright (c) 1997-2004  Jeff Urlwin
@@ -9,7 +9,7 @@
 
 require 5.004;
 
-$DBD::ODBC::VERSION = '1.10';
+$DBD::ODBC::VERSION = '1.11';
 
 {
     package DBD::ODBC;
@@ -20,7 +20,7 @@ $DBD::ODBC::VERSION = '1.10';
     
     @ISA = qw(Exporter DynaLoader);
 
-    # my $Revision = substr(q$Id: ODBC.pm 246 2004-03-26 14:17:35Z jurl $, 13,2);
+    # my $Revision = substr(q$Id: ODBC.pm 484 2004-10-11 19:20:51Z jurl $, 13,2);
 
     require_version DBI 1.21;
 
@@ -620,7 +620,14 @@ to use { odbc_cursortype => DBI::SQL_CURSOR_DYNAMIC } instead.  For example:
 
 See t/20SqlServer.t for an example.
 
-		   
+
+=item odbc_query_timeout 
+
+This allows the end user to set a timeout for queries on the ODBC side.  In your connect, add
+{ odbc_timeout => 30 } or set on the dbh before executing the statement.  The default is 0, no timeout.
+Note that some drivers may not support this attribute.
+
+   
 =item odbc_version (applies to connect only!)
 
 This was added prior to the move to ODBC 3.x to allow the caller to "force" ODBC 3.0
